"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DriverMessageHandler = void 0;
const error_1 = require("../error");
const command_1 = require("./command");
class DriverMessageHandler {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    static async handle(message, driver, client) {
        const { command } = message;
        switch (command) {
            case command_1.DriverCommand.setVerifyCode:
                {
                    const result = await driver.connect(message.verifyCode).catch((error) => {
                        throw error;
                    });
                    return { result: result };
                }
            case command_1.DriverCommand.setCaptcha:
                {
                    let result = false;
                    const captchaId = message.captchaId ? message.captchaId : this.captchaId;
                    this.captchaId = null;
                    if (captchaId) {
                        result = await driver.connect(message.captcha, captchaId).catch((error) => {
                            throw error;
                        });
                    }
                    return { result: result };
                }
            case command_1.DriverCommand.pollRefresh:
                await driver.refreshCloudData().catch((error) => {
                    throw error;
                });
                return {};
            case command_1.DriverCommand.isConnected:
            case command_1.DriverCommand.isConnectedLegacy:
                {
                    const result = driver.isConnected();
                    return { connected: result };
                }
            case command_1.DriverCommand.isPushConnected:
            case command_1.DriverCommand.isPushConnectedLegacy:
                {
                    const result = driver.isPushConnected();
                    return { connected: result };
                }
            case command_1.DriverCommand.connect:
                {
                    const result = await driver.connect().catch((error) => {
                        throw error;
                    });
                    return { connected: result };
                }
            case command_1.DriverCommand.disconnect:
                driver.close();
                return {};
            case command_1.DriverCommand.getVideoEvents:
                {
                    if (client.schemaVersion >= 3) {
                        const fifthyYearsInMilliseconds = 15 * 365 * 24 * 60 * 60 * 1000;
                        const videoMessage = message;
                        let startTime = new Date(new Date().getTime() - fifthyYearsInMilliseconds);
                        let endTime = new Date();
                        if (videoMessage.startTimestampMs !== undefined) {
                            startTime = new Date(videoMessage.startTimestampMs);
                        }
                        if (videoMessage.endTimestampMs !== undefined) {
                            endTime = new Date(videoMessage.endTimestampMs);
                        }
                        const events = await driver.getApi().getVideoEvents(startTime, endTime, videoMessage.filter, videoMessage.maxResults);
                        return { events: events };
                    }
                }
            case command_1.DriverCommand.getAlarmEvents:
                {
                    if (client.schemaVersion >= 3) {
                        const fifthyYearsInMilliseconds = 15 * 365 * 24 * 60 * 60 * 1000;
                        const alarmMessage = message;
                        let startTime = new Date(new Date().getTime() - fifthyYearsInMilliseconds);
                        let endTime = new Date();
                        if (alarmMessage.startTimestampMs !== undefined) {
                            startTime = new Date(alarmMessage.startTimestampMs);
                        }
                        if (alarmMessage.endTimestampMs !== undefined) {
                            endTime = new Date(alarmMessage.endTimestampMs);
                        }
                        const events = await driver.getApi().getAlarmEvents(startTime, endTime, alarmMessage.filter, alarmMessage.maxResults);
                        return { events: events };
                    }
                }
            case command_1.DriverCommand.getHistoryEvents:
                {
                    if (client.schemaVersion >= 3) {
                        const fifthyYearsInMilliseconds = 15 * 365 * 24 * 60 * 60 * 1000;
                        const historyMessage = message;
                        let startTime = new Date(new Date().getTime() - fifthyYearsInMilliseconds);
                        let endTime = new Date();
                        if (historyMessage.startTimestampMs !== undefined) {
                            startTime = new Date(historyMessage.startTimestampMs);
                        }
                        if (historyMessage.endTimestampMs !== undefined) {
                            endTime = new Date(historyMessage.endTimestampMs);
                        }
                        const events = await driver.getApi().getHistoryEvents(startTime, endTime, historyMessage.filter, historyMessage.maxResults);
                        return { events: events };
                    }
                }
            default:
                throw new error_1.UnknownCommandError(command);
        }
    }
}
exports.DriverMessageHandler = DriverMessageHandler;
DriverMessageHandler.captchaId = null;
//# sourceMappingURL=message_handler.js.map